pub fn affine_signature(truth: &[bool]) -> Option<AffineSignature>Expand description
Compute the affine-equivalence signature of a Boolean function from its Walsh spectrum. None if
truth.len() is not a power of two.
pub fn affine_signature(truth: &[bool]) -> Option<AffineSignature>Compute the affine-equivalence signature of a Boolean function from its Walsh spectrum. None if
truth.len() is not a power of two.