pub fn classify_text(text: &str) -> CompressibilityReportExpand description
Classify a text string by the compressibility class of its UTF-8 bytes.
pub fn classify_text(text: &str) -> CompressibilityReportClassify a text string by the compressibility class of its UTF-8 bytes.