pub fn kolmogorov_bound(truth: &[bool]) -> Option<KolmogorovBound>Expand description
Compute a certified Kolmogorov upper bound for a Boolean function via its recursive structure
decomposition. None if truth.len() is not a power of two.
pub fn kolmogorov_bound(truth: &[bool]) -> Option<KolmogorovBound>Compute a certified Kolmogorov upper bound for a Boolean function via its recursive structure
decomposition. None if truth.len() is not a power of two.