structural_bound

Function structural_bound 

pub fn structural_bound(
    num_vars: usize,
    clauses: &[Vec<Lit>],
    generators: &[Perm],
) -> Option<StructuralBound>
Build the structural bound for F under a set of candidate generators. Returns None if any generator is not an automorphism, or if rep + generators does not reconstruct F (so we never issue a certificate we could not re-check).